@@ -1,7 +1,5 @@
 package POEx::WorkerPool::Error::JobError;
-our $VERSION = '0.092800';
-
-
+$POEx::WorkerPool::Error::JobError::VERSION = '1.100910';
 
 #ABSTRACT: An error class indicating something failed with the job
 
@@ -21,7 +19,6 @@ class POEx::WorkerPool::Error::JobError extends POEx::WorkerPool::Error
 1;
 
 
-
 =pod
 
 =head1 NAME
@@ -30,40 +27,39 @@ POEx::WorkerPool::Error::JobError - An error class indicating something failed w
 
 =head1 VERSION
 
-version 0.092800
+version 1.100910
 
 =head1 DESCRIPTION
 
 This exception is thrown when there is an irrecoverable error with a job
 
-=head1 ATTRIBUTES
+=head1 PUBLIC_ATTRIBUTES
 
-=head2 job is: ro, isa: DoesJob
+=head2 job 
+
+ is: ro, isa: DoesJob
 
 This contains the job that errored
 
+=head2 job_status 
 
-
-=head2 job_status is:ro, isa: JobStatus
+ is:ro, isa: JobStatus
 
 This contains the useful information captured from the try block around the job
 during execution of the previous step
 
-
-
 =head1 AUTHOR
 
   Nicholas Perez <nperez@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2009 by Infinity Interactive.
+This software is copyright (c) 2010 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
-
+=cut
 
 
 __END__
